<?php
namespace App;

use DI\ContainerBuilder;
use Interop\Container\ContainerInterface;

class App extends \DI\Bridge\Slim\App {

    protected function configureContainer(ContainerBuilder $builder) {

        $definitions = [
            'settings.displayErrorDetails' => true,
            
            'errorHandler' => function ($c) {
                return function ($request, $response, $e) use ($c) {
                    return $response->withStatus(500)->withJson([
                        'error'   => true,
                        'message' => $e->getMessage(),
                        'result'  => []
                    ]);
                };
            },
            
            \Doctrine\DBAL\Connection::class => function () {

                global $ENVIRONMENT_FILE;

                $environmentFile = $ENVIRONMENT_FILE;
                $environment     = json_decode($environmentFile, true);

                $connection = null;

                if($environment['driver'] == 'oci8') {
                    $dbPassword = $environment['password'];
                    if(isset($environment['encryptedPassword']) && $environment['encryptedPassword']) {
                        $dbPassword = $this->decrypt($environment['password']);
                    }

                    $connection = \Doctrine\DBAL\DriverManager::getConnection(array(
                        'user'        => $environment['user'],
                        'password'    => $dbPassword,
                        'host'        => $environment['host'],
                        'port'        => $environment['port'],
                        'dbname'      => $environment['dbname'],
                        'service'     => $environment['service'],
                        'driver'      => $environment['driver'],
                        'charset'     => $environment['charset'],
                        'sessionMode' => $environment["sessionMode"] === "OCI_CRED_EXT" ? OCI_CRED_EXT : OCI_DEFAULT
                    ), $config = new \Doctrine\DBAL\Configuration);
                    
                } 

                return $connection;
            }
        ];

        $builder->addDefinitions($definitions);
    }
    
    private function decrypt($string) {
        $method     = "AES-256-CBC";
        $secret_key = 'ZEEDHI';
        $secret_iv  = 'ZEEDHI IV';
        $key        = hash('sha256', $secret_key);
        $iv         = substr(hash('sha256', $secret_iv), 0, 16);
        return openssl_decrypt(base64_decode($string), $method, $key, 0, $iv);
    }
}